/*
 * SummaryListFragment 
 * A basic list view fragment example
 * Companion code for Chapter 20, 21
 * Android in Action, 3rd Edition
 * C. Enrique Ortiz | http://www.CEnriqueOrtiz
 * May 2011
 */

package com.cenriqueortiz.androidinaction.ch20_21;

import com.cenriqueortiz.androidinaction.R;
import android.app.ListFragment;
import android.content.Context;
import android.os.Bundle;
import android.view.Gravity;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.Toast;

public class SummaryListFragment extends ListFragment {
	
    // define some values for our simple list adapter example
	private int mPosition, mCategory;

	// List view items to display
	private String[] mListItems = new String[] {
			"Mobility Weblog", 
			"TechCrunch", 
			"Manning Books"};

	// URLs related to each list view item
	private String[] mListItemsUrls = new String[] {
			"http://mobilityweblog.com", 
			"http://www.TechCrunch.com", 
			"http://www.manning.com/"};

	/** Default constructor */
	public SummaryListFragment() {}

	@Override
	/** Invoked when activity has been created */
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        ListView lv = getListView();
        // Set listener for Context-menu long-press
        lv.setOnItemLongClickListener(new OnItemLongClickListener() {
            public boolean onItemLongClick(AdapterView<?> av, View v, int pos, long id) {
                final String title = (String) ((TextView) v).getText();
                showAlert(getActivity(), title);
                return true;
            }
        });    
        
        setListAdapter(new ArrayAdapter<String>(getActivity(),
                R.layout.frag_summary_textview, mListItems));

        // Start with first item activated
        getListView().setChoiceMode(ListView.CHOICE_MODE_SINGLE);
    }
	
	////////////////////////////////////////////////////////////////////////////////////
	    
    @Override
    /** Invoked when the list item has been clicked. */
    public void onListItemClick(ListView lv, View v, int position, long id) {
    	// Based on listview item selection, bring up 
    	//	the corresponding website on the webview
        DetailsWebFragment frag = (DetailsWebFragment) 
        	getFragmentManager().findFragmentById(R.id.frag_details_webview);
        frag.updateDetails(mListItemsUrls[position]);
        lv.setItemChecked(mPosition, false);
        lv.setItemChecked(position, true);
        mPosition = position; // remember current position
    }
    
    ///////////////////////////////////////////////////////////////////////////////////
    
    /** Invoked to select category when a tab selection has been made */
    public void setCategory(int value) {
    	mCategory = value;
    	Toast.makeText(getActivity(), "Setting Category: " + value, Toast.LENGTH_LONG).show();    	
    }
    
    ///////////////////////////////////////////////////////////////////////////////////

    /** Toast helper method */
    public static void showAlert(Context cxt, String text) {
    	if (cxt != null) {
        	int duration = Toast.LENGTH_SHORT;
        	Toast toast = Toast.makeText(cxt, text, duration);
        	toast.setGravity(Gravity.TOP|Gravity.LEFT, 0, 0);
        	toast.show();    	
    	}
    }
}
