/*
 * DetailsWebFragment.java 
 * A sample Web View Fragment with drag/drop
 * Companion code for Chapter 22
 * Android in Action, 3rd Edition
 * C. Enrique Ortiz | http://www.CEnriqueOrtiz
 * May 2011
 */

package com.cenriqueortiz.androidinaction.ch22;

import android.content.ClipData;
import android.content.ClipDescription;
import android.graphics.Color;
import android.os.Bundle;
import android.view.DragEvent;
import android.view.View;
import android.webkit.WebSettings;
import android.webkit.WebView;
import android.webkit.WebViewFragment;

public class DetailsWebFragment extends WebViewFragment {
	// Web view
    WebView mWebView;

	/** Default constructor */
    public DetailsWebFragment() {}
    
    @Override
	/** Invoked when activity has been created */
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        // Get the web view, configure it
        mWebView = getWebView();
        WebSettings webSettings = mWebView.getSettings();
        webSettings.setUseWebViewBackgroundForOverscrollBackground(true);
        webSettings.setJavaScriptEnabled(true);
        webSettings.setSavePassword(false);
        webSettings.setSaveFormData(false);
        webSettings.setSupportZoom(true);                
        webSettings.setLoadWithOverviewMode(true);
        webSettings.setUseWideViewPort(true);        

        ////////////////////////////////////
        // Register the drag event listener
        ////////////////////////////////////
        mWebView.setOnDragListener(new View.OnDragListener() {
            public boolean onDrag(View v, DragEvent event) {
                switch (event.getAction()) {
                    case DragEvent.ACTION_DRAG_STARTED:
                    	// drag started event: accept or not the operation
                        return dragStarted(mWebView, event);
                    case DragEvent.ACTION_DROP:
                    	// drop event: get the data
                        return dropReceived(mWebView, event);                         
                    case DragEvent.ACTION_DRAG_ENTERED:
                    	// view area entered: provide visual cue
                    	mWebView.setBackgroundColor(Color.GRAY);
                    	return true;
                    case DragEvent.ACTION_DRAG_EXITED:
                    	// view area exited: provide visual cue
                    	mWebView.setBackgroundColor(Color.TRANSPARENT);
                    	return true;
                    default:
                        return false;
                }
            }
        });
        
    }
    
    /** Called by the list view to update this web view (with the passed URL) */
    public void updateDetails(String url) {
        mWebView.loadUrl(url);    	
    }   

    /////////////////////////////////////////////////////////////////////////////////
    
    /** Process a ACTION_DRAG_STARTED event */
    private boolean dragStarted(View view, DragEvent event) {
    	// Accept the drag operation and continue processing 
        ClipDescription clipDesc = event.getClipDescription();
        if (clipDesc != null) {
            // return true to accept the operation and receive further events
        	return clipDesc.hasMimeType(ClipDescription.MIMETYPE_TEXT_PLAIN);
    	}
        // return false to not accept the drag operation
        return false;
    }   

    /** Process a ACTION_DROP event */
    private boolean dropReceived(View view, DragEvent event) {
    	// Accept data to move. 
    	// This example assumes text is properly formatted URL.
        ClipData data = event.getClipData();
        if (data != null) {
            if (data.getItemCount() > 0) {
                android.content.ClipData.Item item = data.getItemAt(0);
                String textData = (String) item.getText();
                if (textData != null) {
                	// For this example, assumed properly formed http:// URL
                	updateDetails(textData);
                    return true; // dropped accepted
                }
            }
        }
        return false; // dropped not accepted
    }

}
