/*
 * SummaryListFragment.java 
 * A sample List View Fragment with drag/drop
 * Companion code for Chapter 22
 * Android in Action, 3rd Edition
 * C. Enrique Ortiz | http://www.CEnriqueOrtiz
 * May 2011
 */

package com.cenriqueortiz.androidinaction.ch22;

import com.cenriqueortiz.androidinaction.R;
import android.app.ListFragment;
import android.content.ClipData;
import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Point;
import android.graphics.drawable.ColorDrawable;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.view.Gravity;
import android.view.View;
import android.view.View.DragShadowBuilder;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.AdapterView.OnItemLongClickListener;
import android.widget.Toast;

public class SummaryListFragment extends ListFragment {
	
    // define some values for our simple list adapter example
	private int mPosition, mCategory;

	// List view items to display
	private String[] mListItems = new String[] {
			"Mobility Weblog", 
			"TechCrunch", 
			"Manning Books"};

	// URLs related to each list view item
	private String[] mListItemsUrls = new String[] {
			"http://mobilityweblog.com", 
			"http://www.TechCrunch.com", 
			"http://www.manning.com/"};

	/** Default constructor */
	public SummaryListFragment() {}

	@Override
	/** Invoked when activity has been created */
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        ListView lv = getListView();
        
        // Set listener for Context-menu long-press
        lv.setOnItemLongClickListener(new OnItemLongClickListener() {
            public boolean onItemLongClick(AdapterView<?> av, View v, int pos, long id) {
                final String title = (String) ((TextView) v).getText();
                showAlert(getActivity(), title);
                ///////////////////////
                // Start drag operation
                ///////////////////////
                // Get the data to be dragged
                ClipData data = ClipData.newPlainText(title, mListItemsUrls[pos]);
                // Instantiate the shadow building
        	    DragShadowBuilder shadowBuilder = new MyDragShadowBuilder(v);
        	    // Start the drag operation!
        	    v.startDrag(data, shadowBuilder, v, 0);
                return true;
            }
        });    

        setListAdapter(new ArrayAdapter<String>(getActivity(),
                R.layout.frag_summary_textview, mListItems));

        // Start with first item activated
        getListView().setChoiceMode(ListView.CHOICE_MODE_SINGLE);
    }
	
	////////////////////////////////////////////////////////////////////////////////////
	    
    @Override
    /** Invoked when the list item has been clicked. */
    public void onListItemClick(ListView lv, View v, int position, long id) {
    	// No handling code needed as we are using drag/drop above
    }
    
    ///////////////////////////////////////////////////////////////////////////////////
    
    /** Invoked to select category when a tab selection has been made */
    public void setCategory(int value) {
    	mCategory = value;
    	Toast.makeText(getActivity(), "Setting Category: " + value, Toast.LENGTH_LONG).show();    	
    }
    
    ///////////////////////////////////////////////////////////////////////////////////

    /** Toast helper method */
    public static void showAlert(Context cxt, String text) {
    	if (cxt != null) {
        	int duration = Toast.LENGTH_SHORT;
        	Toast toast = Toast.makeText(cxt, text, duration);
        	toast.setGravity(Gravity.TOP|Gravity.LEFT, 0, 0);
        	toast.show();    	
    	}
    }

    ///////////////////////////////////////////////////////////////////////////////////
    // Shadow builder
    ///////////////////////////////////////////////////////////////////////////////////    

    /** Defines the shadow building */
    private static class MyDragShadowBuilder extends View.DragShadowBuilder {
        // The drawable drag shadow
        private static Drawable mShadow;

        /** Constructor */
        public MyDragShadowBuilder(View v) {
            // Store the View to be dragged
            super(v);
            // Create a light gray colored drawable for our shadow
            mShadow = new ColorDrawable(Color.LTGRAY);
        }

        /** Callback for the drag shadow metrics (dimension and touch point) */ 
        @Override
        public void onProvideShadowMetrics (Point size, Point touch) {
            // Defines local variables
            int width = getView().getWidth();
            int height = getView().getHeight();
            mShadow.setBounds(0, 0, width, height);
            // Sets the size of the shadow to be the same size as the view.
            size.set(width, height);
            // Sets the drag-and-drop touch point to be in the middle of the drag shadow
            touch.set(width / 2, height / 2);
        }

        /** Callback that draws the drag shadow */
        @Override
        public void onDrawShadow(Canvas canvas) {
            super.onDrawShadow(canvas);
            mShadow.draw(canvas);
            getView().draw(canvas);
        }
    }

}

